.. :changelog:

History
-------

1.2.0 (2024-01-02)
++++++++++++++++++

* Added support for Django 5.0 -- fixed ``TypeError: int() argument must be a string`` crash.
* Added support for Python 3.11, 3.12.
* Dropped support for Django 2.2, 4.0, 4.1 (3.2 LTS is still supported).

1.1.0 (2022-10-09)
++++++++++++++++++

* Added support for Django 4.1 -- fixed ``templates.E003`` warning.

1.0.1 (2022-02-03)
++++++++++++++++++

* Fixed unsuccessful 1.0.0 release.

1.0.0 (2022-02-03)
++++++++++++++++++

* Added support for Django 4.0.
* Added support for Python 3.10.
* Dropped support Django 3.0, 3.1 (2.2 LTS is still supported).
* Dropped support for Python 3.6.

0.4.0 (2020-10-20)
++++++++++++++++++

* Modernized the packaging.
* Added support for latest Django.

0.3.0 (2017-11-24)
++++++++++++++++++

* Added RangeBasedDateHierarchyListFilter.

0.2.0 (2017-10-21)
++++++++++++++++++

* Option to provide custom drill down for any level in the hierarchy.


0.1.0 (2017-09-21)
++++++++++++++++++

* First release on PyPI.
